@@ -5,19 +5,19 @@ use crate::{
         dbt::ask_dbt_connector_setup, snowflake::ask_snowflake_connector_setup,
         tableau::ask_tableau_connector_setup,
     },
+    project,
     tui::AltScreenContext,
 };
 
 use std::{collections::HashMap, path::Path};
 
-use anyhow::Result;
+use anyhow::{Context, Result};
 use colored::Colorize;
 use inquire::{
     list_option::ListOption,
     set_global_render_config,
     ui::{RenderConfig, StyleSheet, Styled},
-    validator::Validation,
-    Confirm, MultiSelect, Text,
+    validator::Validation, MultiSelect, Text,
 };
 use jetty_core::jetty::{ConnectorConfig, ConnectorNamespace, CredentialsMap, JettyConfig};
 
@@ -27,6 +27,8 @@ mod snowflake;
 mod tableau;
 mod validation;
 
+const SKIP_CMD: &str = "/skip";
+
 /// Ask the user to respond to a series of questions to create the Jetty
 /// config and the connectors config, producing both.
 pub(crate) async fn inquire_init(
@@ -44,30 +46,13 @@ pub(crate) async fn inquire_init(
     let mut jetty_config = JettyConfig::new();
     let mut credentials = HashMap::new();
 
+    // Set project ID
+    jetty_config.project_id = jetty_core::jetty::new_project_id();
+
     jetty_config.set_name(ask_project_name(overwrite_project_dir, project_name)?);
-    let connector_types = ask_select_connectors()?;
+    let connector_types = ask_select_connectors(false)?;
 
-    for connector in connector_types {
-        println!(
-            "{}",
-            format!("{} connector configuration", connector.color(JETTY_ORANGE)).underline()
-        );
-        let connector_namespace_user_input = ask_connector_namespace(connector)?;
-        let connector_namespace = ConnectorNamespace(connector_namespace_user_input.clone());
-        jetty_config.connectors.insert(
-            connector_namespace.clone(),
-            ConnectorConfig::new(connector.to_owned(), Default::default()),
-        );
-
-        let mut credentials_map = match connector {
-            "dbt" => ask_dbt_connector_setup()?,
-            "snowflake" => ask_snowflake_connector_setup(connector_namespace).await?,
-            "tableau" => ask_tableau_connector_setup().await?,
-            &_ => panic!("Unrecognized input"),
-        };
-        credentials_map.insert("type".to_owned(), connector.to_owned());
-        credentials.insert(connector_namespace_user_input.to_owned(), credentials_map);
-    }
+    update_connector_info(connector_types, &mut jetty_config, &mut credentials).await?;
 
     // Leave the alternate screen.
     alt_screen_context.end();
@@ -120,16 +105,17 @@ fn ask_project_name(
     Ok(project_name)
 }
 
-fn ask_select_connectors() -> Result<Vec<&'static str>> {
+fn ask_select_connectors(skip_dbt_validation: bool) -> Result<Vec<&'static str>> {
     let options = vec!["dbt", "snowflake", "tableau"];
 
-    let validator = |connectors: &[ListOption<&&str>]| {
+    let validator = move |connectors: &[ListOption<&&str>]| {
         if connectors.is_empty() {
             Ok(Validation::Invalid(
                 "Please select one or more connectors.".into(),
             ))
         } else if connectors.iter().any(|i| *i.value == "dbt")
             && !connectors.iter().any(|i| *i.value == "snowflake")
+            && !skip_dbt_validation
         {
             Ok(Validation::Invalid("dbt depends on Snowflake".into()))
         } else {
@@ -152,3 +138,75 @@ fn ask_connector_namespace(name: &str) -> Result<String> {
         .prompt()?;
     Ok(connector_namespace)
 }
+
+/// Allow the user at add new connectors to an existing project.
+pub(crate) async fn inquire_add() -> Result<(JettyConfig, HashMap<String, CredentialsMap>)> {
+    // Create an alternate screen for this scope.
+    let alt_screen_context = AltScreenContext::start()?;
+
+    // Set up render configuration for inquire questions.
+    setup_render_config();
+
+    // Read in the existing configuration
+    let mut jetty_config =
+        JettyConfig::read_from_file(project::jetty_cfg_path_local()).context(format!(
+            "unable to read Jetty Config file at ({}); you must be in an existing project to run 'jetty add'",
+            project::jetty_cfg_path_local().to_string_lossy()
+        ))?;
+    // Read in the existing credentials
+    let mut credentials =
+        jetty_core::fetch_credentials(project::connector_cfg_path()).context(format!(
+            "unable to read Jetty connectors file file at ({}); you must set up a project with 'jetty init' before running 'jetty add'",
+            project::connector_cfg_path().to_string_lossy()
+        ))?;
+
+    let connector_types = ask_select_connectors(true)?;
+
+    update_connector_info(connector_types, &mut jetty_config, &mut credentials).await?;
+
+    // Leave the alternate screen.
+    alt_screen_context.end();
+    Ok((jetty_config, credentials))
+}
+
+/// Given a list of requested connectors and a config and credentials object, fetch and update the config and credentials.
+async fn update_connector_info(
+    connectors: Vec<&str>,
+    config: &mut JettyConfig,
+    credentials: &mut HashMap<String, CredentialsMap>,
+) -> Result<()> {
+    for connector in connectors {
+        println!(
+            "{}",
+            format!("{} connector configuration", connector.color(JETTY_ORANGE)).underline()
+        );
+        let connector_namespace_user_input = ask_connector_namespace(connector)?;
+        let connector_namespace = ConnectorNamespace(connector_namespace_user_input.clone());
+
+        let credentials_map = match connector {
+            "dbt" => ask_dbt_connector_setup(),
+            "snowflake" => ask_snowflake_connector_setup(connector_namespace.clone()).await,
+            "tableau" => ask_tableau_connector_setup().await,
+            &_ => panic!("Unrecognized input"),
+        };
+        let mut credentials_map = match credentials_map {
+            Ok(c) => c,
+            Err(e) => {
+                if e.to_string().contains("skipped") {
+                    continue;
+                } else {
+                    return Err(e);
+                }
+            }
+        };
+
+        config.connectors.insert(
+            connector_namespace,
+            ConnectorConfig::new(connector.to_owned(), Default::default()),
+        );
+
+        credentials_map.insert("type".to_owned(), connector.to_owned());
+        credentials.insert(connector_namespace_user_input.to_owned(), credentials_map);
+    }
+    Ok(())
+}
