@@ -15,7 +15,7 @@ use std::{collections::HashMap, env, sync::Arc, time::Instant};
 use anyhow::{anyhow, bail, Context, Result};
 
 use clap::Parser;
-use firestore::FirestoreDb;
+
 use human_panic::setup_panic;
 
 use jetty_core::{
@@ -23,7 +23,7 @@ use jetty_core::{
     connectors::{ConnectorClient, NewConnector},
     fetch_credentials,
     jetty::JettyConfig,
-    logging::{self, debug, info, LevelFilter},
+    logging::{self, debug, info},
     Connector, Jetty,
 };
 
@@ -37,10 +37,6 @@ pub async fn cli() -> Result<()> {
     // Setup logging
     let reload_handle = logging::setup(None);
 
-    // Set up Firestore Connection
-    let firestore_db = FirestoreDb::new("jetty-cli-telemetry").await;
-    usage_stats::FIRESTORE.set(firestore_db).unwrap();
-
     // Setup panic handler
     setup_panic!(Metadata {
         name: env!("CARGO_PKG_NAME").into(),
@@ -49,7 +45,7 @@ pub async fn cli() -> Result<()> {
         homepage: "get-jetty.com".into(),
     });
     // Get Jetty Config
-    let jetty_config = JettyConfig::read_from_file(&project::jetty_cfg_path_local()).ok();
+    let jetty_config = JettyConfig::read_from_file(project::jetty_cfg_path_local()).ok();
     // Get args
     let args = if env::args().collect::<Vec<_>>().len() == 1 {
         // Invoke telemetry for empty args. If we executed `JettyArgs::parse()` first,
@@ -65,15 +61,14 @@ pub async fn cli() -> Result<()> {
             JettyCommand::Init { .. } => UsageEvent::InvokedInit,
             JettyCommand::Fetch { .. } => UsageEvent::InvokedFetch {
                 connector_types: if let Some(c) = &jetty_config {
-                    c.connectors
-                        .iter()
-                        .map(|(_, c)| c.connector_type.to_owned())
+                    c.connectors.values().map(|c| c.connector_type.to_owned())
                         .collect()
                 } else {
                     vec![]
                 },
             },
             JettyCommand::Explore { .. } => UsageEvent::InvokedExplore,
+            JettyCommand::Add => UsageEvent::InvokedAdd,
         };
         record_usage(event, &jetty_config)
             .await
@@ -140,6 +135,9 @@ pub async fn cli() -> Result<()> {
                 ),
             }
         }
+        JettyCommand::Add => {
+            init::add().await?;
+        }
     }
 
     Ok(())
@@ -162,9 +160,9 @@ async fn fetch(connectors: &Option<Vec<String>>, &visualize: &bool) -> Result<()
 
     let mut data_from_connectors = vec![];
 
-    let selected_connectors;
+    
 
-    selected_connectors = if let Some(conns) = connectors {
+    let selected_connectors = if let Some(conns) = connectors {
         jetty
             .config
             .connectors
